@@ -14,7 +14,6 @@
 # under the License.
 
 import json
-import six
 
 from solum_tempest_plugin import base
 
@@ -23,7 +22,7 @@ class TestSensorController(base.TestCase):
 
     def test_sensors_get_all(self):
         resp, body = self.client.get('v1/sensors')
-        if isinstance(body, six.binary_type):
+        if isinstance(body, bytes):
             body = body.decode('utf-8')
         data = json.loads(body)
         self.assertEqual(200, resp.status)
